<?php
/**
 *  @package Virtualmoney
 *  @copyright Copyright (c)2013 JoomPROD
 *  @license GNU General Public License version 3, or later
 */

// no direct access
defined('_JEXEC') or die('Restricted access');

include_once(JPATH_LIBRARIES.'/fof/include.php');
require_once(JPATH_ADMINISTRATOR.'/components/com_virtualmoney/helpers/format.php');
include_once(JPATH_ADMINISTRATOR.'/components/com_virtualmoney/helpers/cparams.php');
include_once(JPATH_ADMINISTRATOR.'/components/com_virtualmoney/helpers/mail.php');

if(is_file(JPATH_ROOT.'/libraries/juloalib/Lib.php')){
    include_once(JPATH_ROOT.'/libraries/juloalib/Lib.php');
}

// Merge the language overrides
$paths = array(JPATH_ADMINISTRATOR, JPATH_ROOT);
$jlang = JFactory::getLanguage();
$jlang->load("com_virtualmoney", $paths[0], 'en-GB', true);
$jlang->load("com_virtualmoney", $paths[0], null, true);
$jlang->load("com_virtualmoney", $paths[1], 'en-GB', true);
$jlang->load("com_virtualmoney", $paths[1], null, true);

class Virtualmoney {
	
    /**
     * Check if the user had enough credit to purchase the total
     * 
     * @param int $total
     * @param int $userId
     * @return boolean
     */
    public static function checkCredits($total, $userId) {
    	if ($userId == 0)
    		return false;
    	
        $credits = self::getCredits($userId, false, true);
        
        if($credits >= $total) {
            return true;
        }	
        return false;
    }
    
    /**
     * Add the amount of $credits to the account of the user
     * and create a transaction
     * 
     * @param int $userId
     * @param int $newCredits
     * @param string $transactionDescription
     * @param string $source
     * @return boolean
     */
	public static function addCredits($userId, $newCredits, $transactionDescription = '', $source = '', $source_id = 0) {
        $creditModel = FOFModel::getTmpInstance('Credits','VirtualmoneyModel');
        
        $db = JFactory::getDbo();
       	
        $sql = "SELECT * FROM #__virtualmoney_credits WHERE user_id=".(int)$userId;
        $db->setQuery($sql);
        $result = $db->loadObject();
        
        $result->user_id = $userId;
        $result->credits += (float)$newCredits;
        $creditModel->save($result);
        
        //Insert the transaction
        $transaction = new JObject();
        $transaction->user_id = $userId;
        $transaction->credits = $newCredits;
        $transaction->balance = $result->credits;
        $transaction->description = $transactionDescription;
        $transaction->type = $source;
        $transaction->type_id = $source_id;
        $transaction->created_on = date('Y-m-d H:i:s');
        
        $transactionModel = FOFModel::getTmpInstance('Transactions', 'VirtualmoneyModel');
        $transactionModel->save($transaction);
        
        return true;
    }
    
	/**
     * Remove the amount of $credits to the account of the user
     * and create a transaction
     * 
     * @param int $userId
     * @param int $newCredits
     * @param string $transactionDescription
     * @param string $source
     * @return boolean
     */
    public static function removeCredits($userId, $newCredits, $transactionDescription = '', $source = '', $source_id='') {
        $creditModel = FOFModel::getTmpInstance('Credits','VirtualmoneyModel');
        
        $db = JFactory::getDbo();
       	
        $sql = "SELECT * FROM #__virtualmoney_credits WHERE user_id=".(int)$userId;
        $db->setQuery($sql);
        $result = $db->loadObject();
        
        $result->user_id = $userId;
        $result->credits -= (float)$newCredits;
        
        //If, after the remove, the user has less credits than 0 -> error
        if($result->credits < 0) {
            //Error
            return false;
        }
        $creditModel->save($result);

        //Insert the transaction
        $transaction = new JObject();
        $transaction->user_id = $userId;
        $transaction->credits = -$newCredits;
        $transaction->balance = $result->credits;
        $transaction->description = $transactionDescription;
        $transaction->type = $source;
        $transaction->type_id = $source_id;
        $transaction->created_on = date('Y-m-d H:i:s');
        
        $transactionModel = FOFModel::getTmpInstance('Transactions', 'VirtualmoneyModel');
        $transactionModel->save($transaction);
        $id = $transactionModel->getId();
        
        if($transaction->balance <= VirtualmoneyHelperCparams::getParam('warning_amount','10')) {
            VirtualmoneyHelperMail::sendMailByStatus($transaction, 'remove-warning');
        }
            
        return $id;
    }
    
    public static function linkTransactionToContent($transactionId, $contentId) {
        if($contentId != NULL && $contentId != '') {
            $transactionModel = FOFModel::getTmpInstance('Transactions', 'VirtualmoneyModel');
            $transaction = $transactionModel->getItem($transactionId);
            $transaction->ad_id = $contentId;
            $transactionModel->save($transaction);
            
            return true;
        } else {
            return false;
        }
    }
    
    /**
     * get the amount of $credits available in the account of the user
     * 
     * @param int $userId
     * @return int $credits
     */
    public static function getCredits($userId, $addcurrencycode = false,$raw=false) {
       	$credit = 0;
       	
        $db = JFactory::getDbo();
       	
        if ($userId != 0) {
        	$sql = "SELECT * FROM #__virtualmoney_credits WHERE user_id=".(int)$userId;
        	$db->setQuery($sql);
        	$result = $db->loadObject();
        	
        	if ($result !== null) {
        		$credit = $result->credits;
        	}
        }
        	
        if ($raw == true) {
        	return $credit;
        } else {
       		return VirtualmoneyHelperFormat::formatPrice($credit,$addcurrencycode);
        }
    }
    
    /**
     * Returns the transactions of the user
     * 
     * @param int $userid
     * @param int $limit
     * @param int $limitStart
     * @return array
     */
    public static function getTransactions($userId, $limit = 5, $limitStart = 0) {
        $userId = (int)$userId;
        $transactions = FOFModel::getTmpInstance('Transactions','VirtualmoneyModel')
                        ->user_id($userId)
                        ->filter_order('created_on')
                        ->filter_order_Dir('DESC')
                        ->limit($limit)
                        ->limitStart($limitStart)
                        ->getItemList();
		return $transactions;
    }
    
    /**
     * Returns the transactions of the user
     *
     * @param int $userid
     * @param int $limit
     * @param int $limitStart
     * @return array
     */
    public static function getTransactionFromType($type = '', $typeId = 0) {
    
    	if($type == '' || $typeId == 0)
    		return false;
    
    	$db = JFactory::getDbo();
    
    	$query = "SELECT * FROM #__virtualmoney_transactions
				  WHERE type = '".$type."'
				  AND type_id = ".(int)$typeId;
    
    	$db->setQuery($query);
    
    	$transaction = $db->loadObject();
    
    	return $transaction;
    }
    
    /**
     * Returns the orders of the user
     * 
     * @param int $userid
     * @param int $limit
     * @param int $limitStart
     * @return array
     */
    public static function getOrders($userId, $limit = 5, $limitStart = 0) {
        $userId = (int)$userId;
        $orders = FOFModel::getTmpInstance('Orders','VirtualmoneyModel')
                        ->user_id($userId)
                        ->filter_order('created_on')
                        ->filter_order_Dir('DESC')
                        ->limit($limit)
                        ->limitStart($limitStart)
                        ->getItemList();
		return $orders;
    }
	
}
